OC.L10N.register(
    "dav",
    {
    "Calendar" : "Agenda",
    "Tasks" : "Tâches",
    "Personal" : "Personnel",
    "{actor} created calendar {calendar}" : "{actor} a créé l'agenda {calendar}",
    "You created calendar {calendar}" : "Vous avez créé l'agenda {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} a supprimé l'agenda {calendar}",
    "You deleted calendar {calendar}" : "Vous avez supprimé l’agenda {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} a mis à jour l’agenda {calendar}",
    "You updated calendar {calendar}" : "Vous avez mis à jour l’agenda {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} a restauré l’agenda {calendar}",
    "You restored calendar {calendar}" : "Vous avez restauré l’agenda {calendar}",
    "You shared calendar {calendar} as public link" : "Vous avez partagé l’agenda {calendar} avec un lien public ",
    "You removed public link for calendar {calendar}" : "Vous avez supprimé le lien public pour l’agenda {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} a partagé l’agenda {calendar} avec vous",
    "You shared calendar {calendar} with {user}" : "Vous avez partagé l’agenda {calendar} avec {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} a partagé l’agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} a cessé de partager l’agenda {calendar} avec vous",
    "You unshared calendar {calendar} from {user}" : "Vous avez cessé de partager l’agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} a cessé de partager l’agenda {calendar} avec {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} a cessé de partager l’agenda {calendar} avec lui-même",
    "You shared calendar {calendar} with group {group}" : "Vous avez partagé l’agenda {calendar} avec le groupe {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} a partagé l’agenda {calendar} avec le groupe {group}",
    "You unshared calendar {calendar} from group {group}" : "Vous avez cessé de partager l’agenda {calendar} avec le groupe {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} a cessé de partager l’agenda {calendar} avec le groupe {group}",
    "Untitled event" : "Événement sans titre",
    "{actor} created event {event} in calendar {calendar}" : "{actor} a créé l’évènement {event} dans l’agenda {calendar}",
    "You created event {event} in calendar {calendar}" : "Vous avez créé l’évènement {event} dans l’agenda {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} a supprimé l’évènement {event} de l’agenda {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Vous avez supprimé l’évènement {event} de l’agenda {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} a mis à jour l’évènement {event} dans l’agenda {calendar}",
    "You updated event {event} in calendar {calendar}" : "Vous avez mis à jour l’évènement {event} dans l’agenda {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} a déplacé l'événement {event} du calendrier {sourceCalendar} au calendrier {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Vous avez déplacé l'événement {event} du calendrier {sourceCalendar} au calendrier {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} a restauré l’événement {event} dans l’agenda {calendar}",
    "You restored event {event} of calendar {calendar}" : "Vous avez restauré l’événement {event} dans l’agenda {calendar}",
    "Busy" : "Occupé",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} a créé la tâche {todo} dans la liste {calendar}",
    "You created to-do {todo} in list {calendar}" : "Vous avez créé un pense-bête {todo} dans la liste {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} a supprimé un pense-bête {todo} de la liste {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Vous avez supprimé le pense-bête {todo} de la liste {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} a mis à jour le pense-bête {todo} dans la liste {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Vous avez mis à jour le pense-bête {todo} dans la liste {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} a résolu le pense-bête {todo} dans la liste {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Vous avez résolu le pense-bête {todo} dans la liste {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} a réouvert le pense-bête {todo} dans la liste {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Vous avez réouvert le pense-bête {todo} dans la liste {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} a déplacé le pense-bête {todo} de la liste {sourceCalendar} à la liste {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Vous avez déplacé le pense-bête {todo} de la liste {sourceCalendar} à la liste {targetCalendar}",
    "Calendar, contacts and tasks" : "Agenda, contacts et tâches",
    "A <strong>calendar</strong> was modified" : "Un <strong>agenda</strong> a été modifié",
    "A calendar <strong>event</strong> was modified" : "Un <strong>événement</strong> de l’agenda a été modifié",
    "A calendar <strong>to-do</strong> was modified" : "Un calendrier <strong>de tâches</strong> a été modifié",
    "Contact birthdays" : "Anniversaires des contacts",
    "Death of %s" : "Mort de %s",
    "Untitled calendar" : "Calendrier sans titre",
    "Calendar:" : "Agenda :",
    "Date:" : "Date :",
    "Where:" : "Où :",
    "Description:" : "Description :",
    "_%n year_::_%n years_" : ["%n an","%n ans","%n ans"],
    "_%n month_::_%n months_" : ["%n mois","%n mois","%n mois"],
    "_%n day_::_%n days_" : ["%n jour","%n jours","%n jours"],
    "_%n hour_::_%n hours_" : ["%n heure","%n heures","%n heures"],
    "_%n minute_::_%n minutes_" : ["%n minute","%n minutes","%n minutes"],
    "%s (in %s)" : "%s (dans %s)",
    "%s (%s ago)" : "%s (il y a %s)",
    "Calendar: %s" : "Agenda : %s",
    "Date: %s" : "Date : %s ",
    "Description: %s" : "Description : %s",
    "Where: %s" : "Où : %s",
    "%1$s via %2$s" : "%1$s via %2$s",
    "In the past on %1$s for the entire day" : "Dans le passé toute la journée du %1$s ",
    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["Dans une minute le %1$s pour la journée entière","Dans %n minutes le %1$s pour la journée entière","Dans %n minutes le %1$s pour la journée entière"],
    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["Dans une heure le %1$s pour la journée entière","Dans %n heures le %1$s pour la journée entière","Dans %n heures le %1$s pour la journée entière"],
    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["Dans un jour le %1$s pour la journée entière","Dans %n jours le %1$s pour la journée entière","Dans %n jours le %1$s pour la journée entière"],
    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["Dans une semaine le %1$s pour la journée entière","Dans %n semaines le %1$s pour la journée entière","Dans %n semaines le %1$s pour la journée entière"],
    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["Dans un mois toute la journée du %1$s","Dans %n mois toute la journée du %1$s","Dans %n mois toute la journée du %1$s"],
    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["Dans un an toute la journée du %1$s","Dans %n années toute la journée du %1$s","Dans %n années toute la journée du %1$s"],
    "In the past on %1$s between %2$s - %3$s" : "Dans le passé le %1$s entre %2$s - %3$s",
    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["Dans une minute le %1$s entre %2$s - %3$s","Dans %n minutes le %1$s entre %2$s - %3$s","Dans %n minutes le %1$s entre %2$s - %3$s"],
    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["Dans une heure le %1$s entre %2$s et %3$s","Dans %n heures le %1$s entre %2$s et %3$s","Dans %n heures le %1$s entre %2$s et %3$s"],
    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["Demain le %1$s entre %2$s et %3$s","Dans %n jours le %1$s entre %2$s et %3$s","Dans %n jours le %1$s entre %2$s et %3$s"],
    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["La semaine prochaine le %1$s entre %2$s et %3$s","Dans %n semaines le %1$s entre %2$s et %3$s","Dans %n semaines le %1$s entre %2$s et %3$s"],
    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["Dans un mois le %1$s entre %2$s et %3$s","Dans %n mois le %1$s entre %2$s et %3$s","Dans %n mois le %1$s entre %2$s et %3$s"],
    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["L'an prochain le %1$s entre %2$s et %3$s","Dans %n ans le %1$s entre %2$s et %3$s","Dans %n ans le %1$s entre %2$s et %3$s"],
    "Could not generate when statement" : "Impossible de déterminer quand",
    "Every Day for the entire day" : "Chaque jour pour toute la journée",
    "Every Day for the entire day until %1$s" : "Chaque jour pour toute la journée jusqu'au %1$s",
    "Every Day between %1$s - %2$s" : "Chaque jour entre %1$s et %2$s",
    "Every Day between %1$s - %2$s until %3$s" : "Chaque jour entre %1$s et %2$s jusqu'au %3$s",
    "Every %1$d Days for the entire day" : "Tous les %1$d jours pour la journée entière",
    "Every %1$d Days for the entire day until %2$s" : "Tous les %1$d jours pour la journée entière jusqu'au %2$s",
    "Every %1$d Days between %2$s - %3$s" : "Tous les %1$d jours entre %2$s et %3$s",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "Tous les %1$d jours entre %2$s et %3$s jusqu'au %4$s",
    "Could not generate event recurrence statement" : "Impossible de générer la phrase de récurrence de l'événement",
    "Every Week on %1$s for the entire day" : "Chaque semaine le %1$s pour la journée entière",
    "Every Week on %1$s for the entire day until %2$s" : "Chaque semaine le %1$s pour la journée entière jusqu'au%2$s",
    "Every Week on %1$s between %2$s - %3$s" : "Chaque semaine le %1$s entre %2$s et %3$s",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "Chaque semaine le %1$s entre %2$s et %3$s jusqu'au %4$s",
    "Every %1$d Weeks on %2$s for the entire day" : "Toutes les %1$d semaines le %2$s pour la journée entière",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "Toutes les %1$d semaines le %2$s pour la journée entière jusqu'au %3$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "Toutes les %1$d semaines le %2$s entre %3$s et %4$s",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "Toutes les %1$d semaines le %2$s entre %3$s et %4$s jusqu'au %5$s",
    "Every Month on the %1$s for the entire day" : "Chaque mois le %1$s pour la journée entière",
    "Every Month on the %1$s for the entire day until %2$s" : "Chaque mois le %1$s pour la journée entière jusqu'au %2$s",
    "Every Month on the %1$s between %2$s - %3$s" : "Chaque mois le %1$s entre %2$s et %3$s",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "Chaque mois le %1$s entre %2$s et %3$s jusqu'au %4$s",
    "Every %1$d Months on the %2$s for the entire day" : "Tous les %1$d mois le %2$s pour la journée entière",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "Tous les %1$d mois le %2$s pour la journée entière jusqu'au %3$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "Tous les %1$d mois le %2$s entre %3$s et %4$s",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "Tous les %1$d mois le %2$s entre %3$s et %4$s jusqu'au %5$s",
    "Every Year in %1$s on the %2$s for the entire day" : "Chaque année en %1$s le %2$s pour la journée entière",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "Chaque année en %1$s le %2$s pour la journée entière jusqu'au %3$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "Chaque année en %1$s le %2$s entre %3$s et %4$s",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "Chaque année en %1$s le %2$s entre %3$s et %4$s jusqu'au %5$s",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "Tous les %1$d ans en %2$s le %3$s pour la journée entière",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "Tous les %1$d ans en %2$s le %3$s pour la journée entière jusqu'au%4$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "Tous les %1$d ans en %2$s le %3$s entre %4$s et %5$s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "Tous les %1$d ans en %2$s le %3$s entre %4$s - %5$s jusqu'au %6$s",
    "On specific dates for the entire day until %1$s" : "À une date spécifique pour la journée entière jusqu'au %1$s",
    "On specific dates between %1$s - %2$s until %3$s" : "À des dates spécifiques entre %1$s et %2$s jusqu'au %3$s",
    "In the past on %1$s" : "Dans le passé sur %1$s",
    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["Dans une minute sur %1$s","Dans %n minutes sur %1$s","Dans %n minutes sur %1$s"],
    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["Dans une heure sur %1$s","Dans %n heures sur %1$s","Dans %n sur %1$s"],
    "_In a day on %1$s_::_In %n days on %1$s_" : ["Demain le %1$s","Dans %n jours le %1$s","Dans %n jours le %1$s"],
    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["La semaine prochaine le %1$s","Dans %n semaines le %1$s","Dans %n semaines le %1$s"],
    "_In a month on %1$s_::_In %n months on %1$s_" : ["Le mois prochain le %1$s","Dans %n mois le %1$s","Dans %n mois le %1$s"],
    "_In a year on %1$s_::_In %n years on %1$s_" : ["L'an prochain le %1$s","Dans %n ans le %1$s","Dans %n ans le %1$s"],
    "In the past on %1$s then on %2$s" : "Dans le passé le %1$s puis le %2$s",
    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["Dans une minute le %1$s puis le %2$s","Dans %n minutes le %1$s puis le %2$s","Dans %n minutes le %1$s puis le %2$s"],
    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["Dans une heure le %1$s puis le %2$s","Dans %n heures le %1$s puis le %2$s","Dans %n heures le %1$s puis le %2$s"],
    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["Demain le %1$s puis le %2$s","Dans %n jours le %1$s puis le %2$s","Dans %n jours le %1$s puis le %2$s"],
    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["La semaine prochaine le %1$s puis le %2$s","Dans %n semaines le %1$s puis le %2$s","Dans %n semaines le %1$s puis le %2$s"],
    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["Le mois prochain le %1$s puis le %2$s","Dans %n mois le %1$s puis le %2$s","Dans %n mois le %1$s puis le %2$s"],
    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["L'an prochain le %1$s puis le %2$s","Dans %n ans le %1$s puis le %2$s","Dans %n ans le %1$s puis le %2$s"],
    "In the past on %1$s then on %2$s and %3$s" : "Dans le passé le %1$s puis le %2$s et %3$s",
    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["Dans une minute le %1$s puis le %2$s et %3$s","Dans %n minutes le %1$s puis le %2$s et %3$s","Dans %n minutes le %1$s puis le %2$s et %3$s"],
    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["Dans une heure le %1$s puis le %2$s et %3$s","Dans %n heures le %1$s puis le %2$s et %3$s","Dans %n heures le %1$s puis le %2$s et %3$s"],
    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["Demain le %1$s puis le %2$s et %3$s","Dans %n jours le %1$s puis le %2$s et %3$s","Dans %n jours le %1$s puis le %2$s et %3$s"],
    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["La semaine prochaine le %1$s puis le %2$s et %3$s","Dans %n semaines le %1$s puis le %2$s et %3$s","Dans %n semaines le %1$s puis le %2$s et %3$s"],
    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["Dans un mois le %1$s puis le %2$s et %3$s","Dans %n mois le %1$s puis le %2$s et %3$s","Dans %n mois le %1$s puis le %2$s et %3$s"],
    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["Dans un an sur %1$spuis sur %2$s et %3$s","Dans %n années sur %1$s puis sur %2$s et %3$s","Dans %n années sur %1$s puis sur %2$s et %3$s"],
    "Could not generate next recurrence statement" : "Impossible de déterminer la prochaine récurrence",
    "Cancelled: %1$s" : "Annulé : %1$s",
    "\"%1$s\" has been canceled" : "\"%1$s\" a été annulé(e)",
    "Re: %1$s" : "Re : %1$s",
    "%1$s has accepted your invitation" : "%1$s a accepté votre invitation",
    "%1$s has tentatively accepted your invitation" : "%1$s a provisoirement accepté votre invitation",
    "%1$s has declined your invitation" : "%1$s a décliné votre invitation",
    "%1$s has responded to your invitation" : "%1$s a répondu à votre invitation",
    "Invitation updated: %1$s" : "Invitation mise à jour : %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s a mis à jour l'évènement %2$s",
    "Invitation: %1$s" : "Invitation : %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s souhaite vous inviter à \"%2$s\"",
    "Organizer:" : "Organisateur :",
    "Attendees:" : "Participants :",
    "Title:" : "Titre :",
    "When:" : "Quand :",
    "Location:" : "Lieu :",
    "Link:" : "Lien :",
    "Occurring:" : "Ayant lieu : ",
    "Accept" : "Accepter",
    "Decline" : "Décliner",
    "More options …" : "Plus d'options…",
    "More options at %s" : "Plus d'options à %s",
    "Monday" : "Lundi",
    "Tuesday" : "Mardi",
    "Wednesday" : "Mercredi",
    "Thursday" : "Jeudi",
    "Friday" : "Vendredi",
    "Saturday" : "Samedi",
    "Sunday" : "Dimanche",
    "January" : "Janvier",
    "February" : "Février",
    "March" : "Mars",
    "April" : "Avril",
    "May" : "Mai",
    "June" : "Juin",
    "July" : "Juillet",
    "August" : "Août",
    "September" : "Septembre",
    "October" : "Octobre",
    "November" : "Novembre",
    "December" : "Décembre",
    "First" : "Première",
    "Second" : "Deuxième",
    "Third" : "Troisième",
    "Fourth" : "Quatrième",
    "Fifth" : "Cinquième",
    "Last" : "Dernièr",
    "Second Last" : "Avant-dernier",
    "Third Last" : "Troisième dernier",
    "Fourth Last" : "Quatrième dernier",
    "Fifth Last" : "Cinquième dernier",
    "Contacts" : "Contacts",
    "{actor} created address book {addressbook}" : "{actor} a créé le carnet d'adresses {addressbook}",
    "You created address book {addressbook}" : "Vous avez créé le carnet d'adresses {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} a supprimé le carnet d'adresses {addressbook}",
    "You deleted address book {addressbook}" : "Vous avez supprimé le carnet d'adresses {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} a mis à jour le carnet d'adresses {addressbook}",
    "You updated address book {addressbook}" : "Vous avez mis à jour le carnet d'adresses {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} a partagé le carnet d'adresses {addressbook} avec vous",
    "You shared address book {addressbook} with {user}" : "Vous avez partagé le carnet d'adresses {addressbook} avec {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} a partagé le carnet d'adresses {addressbook} avec {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} a cessé de partager le carnet d'adresses {addressbook} vous appartenant",
    "You unshared address book {addressbook} from {user}" : "Vous avez cessé de partager le carnet d'adresses {addressbook} appartenant à {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} a cessé de partager le carnet d'adresses {addressbook} appartenant à {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} a cessé de partager le carnet d'adresses {addressbook} lui appartenant",
    "You shared address book {addressbook} with group {group}" : "Vous avez partagé le carnet d'adresses {addressbook} avec le groupe {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} a partagé le carnet d'adresses {addressbook} avec le groupe {group}",
    "You unshared address book {addressbook} from group {group}" : "Vous avez cessé de partager le carnet d'adresses {addressbook} appartenant au groupe {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} a cessé de partager le carnet d'adresses {addressbook} appartenant au groupe {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} a créé le contact {card} dans le carnet d'adresses {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Vous avez créé le contact {card} dans le carnet d'adresses {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} a supprimé le contact {card} dans le carnet d'adresses {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Vous avez supprimé le contact {card} dans le carnet d'adresses {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} a mis à jour le contact {card} dans le carnet d'adresses {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Vous avez mis à jour le contact {card} dans le carnet d'adresses {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Un <strong>contact</strong> ou <strong>carnet d'adresses</strong> a été modifié",
    "Accounts" : "Comptes",
    "System address book which holds all accounts" : "Carnet d'adresses système qui regroupe tous les comptes",
    "File is not updatable: %1$s" : "Ce fichier ne peut pas être mis à jour : %1$s",
    "Failed to get storage for file" : "Impossible d'obtenir l'espace de stockage pour le fichier",
    "Could not write to final file, canceled by hook" : "Impossible d'écrire dans le fichier final, annulé par le hook",
    "Could not write file contents" : "Impossible d'écrire le contenu du fichier",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octets","%n octets"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Erreur en copiant le fichier à destination (copié : %1$s, taille du fichier attendue : %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Taille du fichier attendue : %1$s mais taille du fichier lue (depuis le client Nextcloud) et écrit (dans le stockage Nextcloud) : %2$s. Cela peut être un problème de réseau au niveau du client ou un problème de stockage au niveau du serveur.",
    "Could not rename part file to final file, canceled by hook" : "Impossible de renommer le fichier partiel en fichier final, annulé par le hook",
    "Could not rename part file to final file" : "Impossible de renommer le fichier partiel en fichier définitif.",
    "Failed to check file size: %1$s" : "Échec à la vérification de la taille du fichier : %1$s",
    "Could not open file: %1$s, file does seem to exist" : "Impossible d'ouvrir le fichier %1$s, le fichier semble présent.",
    "Could not open file: %1$s, file doesn't seem to exist" : "Impossible d'ouvrir le fichier %1$s, le fichier ne semble pas présent.",
    "Encryption not ready: %1$s" : "Encryption pas prête : %1$s",
    "Failed to open file: %1$s" : "Échec à l'ouverture du fichier : %1$s",
    "Failed to unlink: %1$s" : "Échec à la suppression :%1$s",
    "Failed to write file contents: %1$s" : "Échec à l'écriture du contenu du fichier : %1$s",
    "File not found: %1$s" : "Fichier non trouvé : %1$s",
    "Invalid target path" : "Chemin d’accès invalide",
    "System is in maintenance mode." : "Le système est en mode maintenance.",
    "Upgrade needed" : "Mise à jour requise",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Votre %s a besoin d'être configuré pour utiliser le HTTPS dans le but d'utiliser CalDAV et CardDAV avec iOS/macOS.",
    "Configures a CalDAV account" : "Configure un compte CalDAV",
    "Configures a CardDAV account" : "Configure un compte CardDAV",
    "Events" : "Évènements",
    "Untitled task" : "Tâche sans titre",
    "Completed on %s" : "Terminé le %s",
    "Due on %s by %s" : "Echéance le %s pour %s",
    "Due on %s" : "Echéance le %s",
    "Example event - open me!" : "Exemple d'événement - ouvrez-moi !",
    "System Address Book" : "Carnet d'adresses du système",
    "The system address book contains contact information for all users in your instance." : "Le carnet d'adresses du système contient les informations de contact de tous les utilisateurs de votre instance.",
    "Enable System Address Book" : "Activer le carnet d'adresses du système",
    "DAV system address book" : "Carnet d'adresses système DAV",
    "No outstanding DAV system address book sync." : "Pas de synchronisation DAV en cours du carnet d'adresses système.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "La synchronisation du carnet d'adresses système DAV n'a pas encore été effectuée car votre instance a plus de 1 000 utilisateurs ou parce qu'une erreur est survenue. Merci de l'exécuter manuellement en tapant la commande \"occ dav:sync-system-addressbook\".",
    "WebDAV endpoint" : "Point de terminaison WebDAV",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Impossible de vérifier si votre serveur web est correctement configuré pour permettre la synchronisation de fichiers via WebDAV. Veuillez vérifier manuellement.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Votre serveur web n’est pas encore correctement configuré pour la synchronisation de fichiers parce que l’interface WebDAV semble ne pas fonctionner.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "Votre serveur web est correctement configuré pour permettre la synchronisation de fichiers via WebDAV.",
    "Migrated calendar (%1$s)" : "Agenda migré (%1$s)",
    "Calendars including events, details and attendees" : "Calendriers incluant des événements, détails et participants",
    "Contacts and groups" : "Contacts et groupes",
    "WebDAV" : "WebDAV",
    "Absence saved" : "Message d’absence sauvegardé",
    "Failed to save your absence settings" : "L'enregistrement des paramètres d'absence a échoué",
    "Absence cleared" : "Message d’absence supprimé",
    "Failed to clear your absence settings" : "Les paramètres d'absence n'ont pas été effacés",
    "First day" : "Premier jour",
    "Last day (inclusive)" : "Dernier jour (inclus)",
    "Out of office replacement (optional)" : "Remplaçant pendant l'absence (optionnel)",
    "Name of the replacement" : "Nom du remplaçant",
    "No results." : "Pas de résultat.",
    "Start typing." : "Commencez à taper.",
    "Short absence status" : "Résumé du message d’absence",
    "Long absence Message" : "Message d’absence complet",
    "Save" : "Enregistrer",
    "Disable absence" : "Désactiver le message d’absence",
    "Failed to load availability" : "Impossible de charger les disponibilités",
    "Saved availability" : "Disponibilités sauvegardées",
    "Failed to save availability" : "Impossible de sauvegarder les disponibilités",
    "Time zone:" : "Fuseau horaire :",
    "to" : "à",
    "Delete slot" : "Supprimer le créneau",
    "No working hours set" : "Heures de travail non définies",
    "Add slot" : "Ajouter un créneau",
    "Weekdays" : "Jours de la semaine",
    "Pick a start time for {dayName}" : "Choisissez une heure de début pour {dayName}",
    "Pick a end time for {dayName}" : "Choisissez une heure de fin pour {dayName}",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Définir automatiquement le statut « Ne pas déranger » en dehors des heures de disponibilités pour désactiver toutes les notifications.",
    "Cancel" : "Annuler",
    "Import" : "Importation",
    "Error while saving settings" : "Erreur lors de l'enregistrement des paramètres",
    "Contact reset successfully" : "Contact réinitialisé avec succès",
    "Error while resetting contact" : "Erreur lors de la remise à zéro du contact",
    "Contact imported successfully" : "Contact importé avec succès",
    "Error while importing contact" : "Erreur lors de l'importation du contact",
    "Import contact" : "Importer un contact",
    "Reset to default" : "Restaurer les valeurs par défaut",
    "Import contacts" : "Importer des contacts",
    "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "Importer un nouveau fichier .vcf supprimera le contact par défaut existant et le remplacera. Voulez-vous continuer ?",
    "Failed to save example event creation setting" : "Échec de la sauvegarde du paramètre de l'exemple de création d'événement",
    "Failed to upload the example event" : "Échec du téléversement de l'exemple d'événement",
    "Custom example event was saved successfully" : "L'exemple d'événement personnalisé a bien été enregistré",
    "Failed to delete the custom example event" : "Échec de la suppression de l'exemple d'événement personnalisé ",
    "Custom example event was deleted successfully" : "L'exemple de contenu personnalisé a bien été supprimé",
    "Import calendar event" : "Importer l'événement du calendrier",
    "Uploading a new event will overwrite the existing one." : "Charger un nouvel événement qui va remplacer l'actuel.",
    "Upload event" : "Téléverser un événement",
    "Availability" : "Disponibilités",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Si vous configurez vos heures de travail, les autres personnes verront si vous êtes disponible quand ils planifient une réunion.",
    "Absence" : "Absence",
    "Configure your next absence period." : "Configurez votre prochaine période d'absence.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Installer aussi {calendarappstoreopen}l'application Calendrier{linkclose}, ou {calendardocopen}connecter à votre PC & téléphone pour synchroniser ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Merci de vérifier d'avoir correctement configuré {emailopen}le serveur de messagerie{linkclose}.",
    "Calendar server" : "Serveur de calendrier",
    "Send invitations to attendees" : "Envoyer des invitations aux participants",
    "Automatically generate a birthday calendar" : "Générer automatiquement un agenda d’anniversaire",
    "Birthday calendars will be generated by a background job." : "Les agendas d’anniversaire seront générés par une tâche en arrière-plan.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Par conséquent, ils ne seront pas disponibles immédiatement après l'activation mais apparaîtront après un certain temps.",
    "Send notifications for events" : "Envoyer une notification pour les évènements",
    "Notifications are sent via background jobs, so these must occur often enough." : "Les notifications sont envoyées par des tâches de fond qui doivent, par conséquent, être exécutées régulièrement.",
    "Send reminder notifications to calendar sharees as well" : "Envoyez également des notifications de rappel aux personnes partageant le calendrier",
    "Reminders are always sent to organizers and attendees." : "Des rappels sont toujours envoyés aux organisateurs et aux participants.",
    "Enable notifications for events via push" : "Activer les notifications push pour les évènements",
    "Example content" : "Exemple de contenu",
    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "Les exemples de contenu servent à présenter les fonctionnalités de Nextcloud. Le contenu par défaut est fourni avec Nextcloud et peut être remplacé par du contenu personnalisé.",
    "There was an error updating your attendance status." : "Une erreur s'est produite lors de la mise à jour de votre statut de présence.",
    "Please contact the organizer directly." : "Merci de contacter l'organisateur directement.",
    "Are you accepting the invitation?" : "Acceptez-vous l'invitation ?",
    "Tentative" : "Tentative",
    "Your attendance was updated successfully." : "Votre présence a été mise à jour avec succès."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
